@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
@@ -114,6 +114,11 @@ sub mapping {
       [like_debian,
        [package => 'libgtk2.0-dev']]],
 
+     [cpanmod => 'App::Stacktrace',
+      # does not work with freebsd anyway
+      [like_debian,
+       [package => 'gdb']]],
+
      [cpanmod => 'Archive::Rar',
       [os_freebsd,
        [package => 'rar'], # restricted, no binary package available, must build from ports
@@ -383,6 +388,11 @@ sub mapping {
       [like_debian,
        [package => 'firebird-dev']]],
 
+     [cpanmod => 'DBD::mysql',
+      # XXX freebad?
+      [like_debian,
+       [package => 'libmysqlclient-dev']]],
+
      [cpanmod => 'DBD::ODBC',
       [os_freebsd,
        [package => 'unixODBC']],
@@ -514,13 +524,19 @@ sub mapping {
       [like_debian,
        [package => 'libshp-dev']]],
 
-     [cpanmod => 'Gimp',
+     [cpanmod => ['Gimp', 'Alien::Gimp'],
       [os_freebsd,
        [package => 'gimp-app']],
       [like_debian,
        [package => 'libgimp2.0-dev'], # 90 MB for package + deps
       ]],
 
+     [cpanmod => 'GitDDL::Migrator',
+      # XXX freebsd?
+      [like_debian,
+       [package => 'mysql-server-5.5'], # possible alternative: mariadb-server-10.0; mysql-server-core-5.5 is not enough as resolveip is usually required
+      ]],
+
      [cpanmod => 'Git::Raw',
       [os_freebsd,
        [package => 'libssh2']],
@@ -607,7 +623,7 @@ sub mapping {
       [like_debian,
        [package => 'libsane-dev']]],
 
-     [cpanmod => 'GraphViz',
+     [cpanmod => ['GraphViz', 'GraphViz2::Marpa'],
       # package named the same in freebsd and debian, maybe everywhere?
       [package => 'graphviz']],
 
@@ -616,6 +632,11 @@ sub mapping {
       [like_debian,
        [package => 'libgnokii-dev']]],
 
+     [cpanmod => 'Gtk2',
+      # XXX freebsd?
+      [like_debian,
+       [package => 'libgtk2.0-dev']]],
+
      [cpanmod => 'Gtk3',
       [os_freebsd,
        # additionally dbus has to be enabled and started
@@ -952,6 +973,12 @@ sub mapping {
        ],
        [package => 'libnanomsg-dev']]],
 
+     [cpanmod => 'Net::DBus',
+      [os_freebsd,
+       [package => ['dbus', 'pkgconf']]],
+      [like_debian,
+       [package => ['libdbus-1-dev', 'pkg-config | pkgconf']]]],
+
      [cpanmod => 'Net::DBus::GLib',
       [os_freebsd,
        [package => 'dbus-glib']],
@@ -1038,9 +1065,14 @@ sub mapping {
      [cpanmod => 'Net::WDNS',
       [os_freebsd,
        [package => 'wdns']],
-      # XXX what about debian?
+      # not available for debian/wheezy and jessie
      ],
 
+     [cpanmod => 'Net::Z3950::ZOOM',
+      # XXX freebsd?
+      [like_debian,
+       [package => 'libyaz-dev']]],
+
      [cpanmod => ['Net::ZooKeeper', 'ZooKeeper'],
       [os_freebsd,
        [package => 'libzookeeper']],
@@ -1316,10 +1348,14 @@ sub mapping {
      ],
 
      [cpanmod => 'Tk',
+      # freetype2 and libXft are optional, but highly recommended as it provides nicer fonts
+      # jpeg and png is bundled in Tk, but usually the Tk version is older
       [os_freebsd,
-       [# freetype2 and libXft are optional, but highly recommended as it provides nicer fonts
-	package => ['freetype2', 'libXft', 'libX11']]],
-      # XXX what about debian?
+       [package => qw(freetype2 libXft libX11 jpeg png)]],
+      [like_debian,
+       [package => [qw(libx11-dev libfreetype6-dev libxft-dev libpng-dev libz-dev libjpeg-dev)]]],
+      [linuxdistro => '~fedora',
+       [package => [qw(libX11-devel libXft-devel libpng-devel zlib-devel libjpeg-devel)]]],
      ],
 
      [cpanmod => 'Tk::TIFF',
@@ -1372,6 +1408,12 @@ sub mapping {
       # XXX what about debian?
      ],
 
+     [cpanmod => 'XML::LibXML',
+      [os_freebsd,
+       [package => 'libxml2']],
+      [like_debian,
+       [package => 'libxml2-dev']]],
+
      [cpanmod => 'XML::LibXSLT',
       [os_freebsd,
        [package => 'libxslt']],
